| Title: | Tools for Handling Extraction of Features from Time Series |
|---|---|
| Description: | Consolidates and calculates different sets of time-series features from multiple 'R' and 'Python' packages including 'Rcatch22' Henderson, T. (2021) <doi:10.5281/zenodo.5546815>, 'feasts' O'Hara-Wild, M., Hyndman, R., and Wang, E. (2021) <https://CRAN.R-project.org/package=feasts>, 'tsfeatures' Hyndman, R., Kang, Y., Montero-Manso, P., Talagala, T., Wang, E., Yang, Y., and O'Hara-Wild, M. (2020) <https://CRAN.R-project.org/package=tsfeatures>, 'tsfresh' Christ, M., Braun, N., Neuffer, J., and Kempa-Liehr A.W. (2018) <doi:10.1016/j.neucom.2018.03.067>, 'TSFEL' Barandas, M., et al. (2020) <doi:10.1016/j.softx.2020.100456>, and 'Kats' Facebook Infrastructure Data Science (2021) <https://facebookresearch.github.io/Kats/>. |
| Authors: | Trent Henderson [cre, aut], Annie Bryant [ctb] |
| Maintainer: | Trent Henderson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.8.4 |
| Built: | 2026-05-14 09:38:45 UTC |
| Source: | https://github.com/hendersontrent/theft |
Compute features on an input time series dataset
calculate_features( data, feature_set = c("catch22", "feasts", "tsfeatures", "kats", "tsfresh", "tsfel", "hctsa", "quantiles", "moments"), features = NULL, catch24 = FALSE, tsfresh_cleanup = FALSE, use_compengine = FALSE, seed = 123, z_score = FALSE, n_jobs = 0, warn = TRUE )calculate_features( data, feature_set = c("catch22", "feasts", "tsfeatures", "kats", "tsfresh", "tsfel", "hctsa", "quantiles", "moments"), features = NULL, catch24 = FALSE, tsfresh_cleanup = FALSE, use_compengine = FALSE, seed = 123, z_score = FALSE, n_jobs = 0, warn = TRUE )
data |
|
feature_set |
|
features |
named |
catch24 |
|
tsfresh_cleanup |
|
use_compengine |
|
seed |
|
z_score |
|
n_jobs |
|
warn |
|
object of class feature_calculations that contains the summary statistics for each feature
Trent Henderson
featMat <- calculate_features(data = simData, feature_set = "catch22")featMat <- calculate_features(data = simData, feature_set = "catch22")
Check for presence of NAs and non-numerics in a vector
check_vector_quality(x)check_vector_quality(x)
x |
input |
Boolean of whether the data is good to extract features on or not
Trent Henderson
The variables include:
feature_listfeature_list
A tidy data frame with 2 variables:
Name of the set the feature is from
Name of the feature
Communicate to R the Python virtual environment containing the relevant libraries for calculating features
init_theft(venv, hctsa = FALSE)init_theft(venv, hctsa = FALSE)
venv |
|
hctsa |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test") init_theft("theft-test") ## End(Not run)## Not run: install_python_pkgs("theft-test") init_theft("theft-test") ## End(Not run)
Communicate to R the Python virtual environment containing pyhctsa only
init_theft_hctsa(venv)init_theft_hctsa(venv)
venv |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test") init_theft_hctsa("theft-test") ## End(Not run)## Not run: install_python_pkgs("theft-test") init_theft_hctsa("theft-test") ## End(Not run)
Communicate to R the Python virtual environment containing kats only
init_theft_kats(venv)init_theft_kats(venv)
venv |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test") init_theft_kats("theft-test") ## End(Not run)## Not run: install_python_pkgs("theft-test") init_theft_kats("theft-test") ## End(Not run)
Communicate to R the Python virtual environment containing tsfel only
init_theft_tsfel(venv)init_theft_tsfel(venv)
venv |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test") init_theft_tsfel("theft-test") ## End(Not run)## Not run: install_python_pkgs("theft-test") init_theft_tsfel("theft-test") ## End(Not run)
Communicate to R the Python virtual environment containing tsfresh only
init_theft_tsfresh(venv)init_theft_tsfresh(venv)
venv |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test") init_theft_tsfresh("theft-test") ## End(Not run)## Not run: install_python_pkgs("theft-test") init_theft_tsfresh("theft-test") ## End(Not run)
Download and install Kats from Python into a new virtual environment
install_kats(venv, python)install_kats(venv, python)
venv |
|
python |
|
no return value; called for side effects
Trent Henderson
## Not run: install_kats("theft-test", "/usr/local/bin/python3.10") ## End(Not run)## Not run: install_kats("theft-test", "/usr/local/bin/python3.10") ## End(Not run)
Download and install pyhctsa from Python into a new virtual environment
install_pyhctsa(venv, python)install_pyhctsa(venv, python)
venv |
|
python |
|
no return value; called for side effects
Trent Henderson
## Not run: install_pyhctsa("theft-test", "/usr/local/bin/python3.10") ## End(Not run)## Not run: install_pyhctsa("theft-test", "/usr/local/bin/python3.10") ## End(Not run)
Download and install tsfresh, TSFEL, and Kats from Python into a new virtual environment
install_python_pkgs(venv, python, hctsa = FALSE)install_python_pkgs(venv, python, hctsa = FALSE)
venv |
|
python |
|
hctsa |
|
no return value; called for side effects
Trent Henderson
## Not run: install_python_pkgs("theft-test", "/usr/local/bin/python3.10") ## End(Not run)## Not run: install_python_pkgs("theft-test", "/usr/local/bin/python3.10") ## End(Not run)
Download and install TSFEL from Python into a new virtual environment
install_tsfel(venv, python)install_tsfel(venv, python)
venv |
|
python |
|
no return value; called for side effects
Trent Henderson
## Not run: install_tsfel("theft-test", "/usr/local/bin/python3.10") ## End(Not run)## Not run: install_tsfel("theft-test", "/usr/local/bin/python3.10") ## End(Not run)
Download and install tsfresh from Python into a new virtual environment
install_tsfresh(venv, python)install_tsfresh(venv, python)
venv |
|
python |
|
no return value; called for side effects
Trent Henderson
## Not run: install_tsfresh("theft-test", "/usr/local/bin/python3.10") ## End(Not run)## Not run: install_tsfresh("theft-test", "/usr/local/bin/python3.10") ## End(Not run)
Calculate a kurtosis of a vector
kurtosis(y)kurtosis(y)
y |
|
numeric scalar of kurtosis
Trent Henderson
Calculate a basic set of the four moments of the distribution
moments(y)moments(y)
y |
|
data.frame of results
Trent Henderson
Load in hctsa formatted MATLAB files of time series data into a tidy format ready for feature extraction
process_hctsa_file(data)process_hctsa_file(data)
data |
|
an object of class data.frame in tidy format
Trent Henderson
Calculate a basic set of quantiles for an input time-series vector
quantiles(y, quantiles = seq(0, 1, by = 0.01))quantiles(y, quantiles = seq(0, 1, by = 0.01))
y |
|
quantiles |
|
data.frame of results
Trent Henderson
The variables include:
simDatasimData
A tidy tsibble with 4 variables:
Unique identifier for the time series
Time index
Value
Group label for the type of time series
Calculate a skewness of a vector
skewness(y)skewness(y)
y |
|
numeric scalar of skewness
Trent Henderson
Tools for Handling Extraction of Features from Time-series